@@ -1,19 +1,11 @@
-"""Define a browser view for the operun Link content type.
-"""
-
-from Acquisition import aq_inner
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from zope.component import getMultiAdapter
 from AccessControl import getSecurityManager
 from Products.CMFCore.permissions import ModifyPortalContent
 
-from Products.CMFCore.utils import getToolByName
-
 from operun.linkportlet.interfaces import IOperunLink
 
-from plone.memoize.instance import memoize 
-
 class OperunLinkView(BrowserView):
     """Default view of an operun Link
     """
@@ -25,8 +17,6 @@ class OperunLinkView(BrowserView):
         if sm.checkPermission(ModifyPortalContent, self.context):
             return self.template()
         else:
-            # the current user is not allowed to see this content - 
-            # redirect to the portal url
             portal_state = getMultiAdapter((self.context, self.request), name=u"plone_portal_state")
             self.request.RESPONSE.redirect(portal_state.portal_url())
             return ''
\ No newline at end of file
